pub struct DataServiceClient<T> { /* private fields */ }Expand description
DataService is the “data plane” for structured VCS reads.
Implementations
Sourceimpl<T> DataServiceClient<T>where
T: GrpcService<Body>,
T::Error: Into<StdError>,
T::ResponseBody: Body<Data = Bytes> + Send + 'static,
<T::ResponseBody as Body>::Error: Into<StdError> + Send,
impl<T> DataServiceClient<T>where
T: GrpcService<Body>,
T::Error: Into<StdError>,
T::ResponseBody: Body<Data = Bytes> + Send + 'static,
<T::ResponseBody as Body>::Error: Into<StdError> + Send,
pub fn new(inner: T) -> Self
pub fn with_origin(inner: T, origin: Uri) -> Self
pub fn with_interceptor<F>(
inner: T,
interceptor: F,
) -> DataServiceClient<InterceptedService<T, F>>where
F: Interceptor,
T::ResponseBody: Default,
T: Service<Request<Body>, Response = Response<<T as GrpcService<Body>>::ResponseBody>>,
<T as Service<Request<Body>>>::Error: Into<StdError> + Send + Sync,
Sourcepub fn send_compressed(self, encoding: CompressionEncoding) -> Self
pub fn send_compressed(self, encoding: CompressionEncoding) -> Self
Compress requests with the given encoding.
This requires the server to support it otherwise it might respond with an error.
Sourcepub fn accept_compressed(self, encoding: CompressionEncoding) -> Self
pub fn accept_compressed(self, encoding: CompressionEncoding) -> Self
Enable decompressing responses.
Sourcepub fn max_decoding_message_size(self, limit: usize) -> Self
pub fn max_decoding_message_size(self, limit: usize) -> Self
Limits the maximum size of a decoded message.
Default: 4MB
Sourcepub fn max_encoding_message_size(self, limit: usize) -> Self
pub fn max_encoding_message_size(self, limit: usize) -> Self
Limits the maximum size of an encoded message.
Default: usize::MAX
Sourcepub async fn get_apply_ops_policy(
&mut self,
request: impl IntoRequest<GetApplyOpsPolicyRequest>,
) -> Result<Response<GetApplyOpsPolicyResponse>, Status>
pub async fn get_apply_ops_policy( &mut self, request: impl IntoRequest<GetApplyOpsPolicyRequest>, ) -> Result<Response<GetApplyOpsPolicyResponse>, Status>
Returns server limits for ApplyOps payload shaping.
Sourcepub async fn resolve_ref(
&mut self,
request: impl IntoRequest<ResolveRefRequest>,
) -> Result<Response<ResolveRefResponse>, Status>
pub async fn resolve_ref( &mut self, request: impl IntoRequest<ResolveRefRequest>, ) -> Result<Response<ResolveRefResponse>, Status>
Refs (read-only)
pub async fn list_refs( &mut self, request: impl IntoRequest<ListRefsRequest>, ) -> Result<Response<ListRefsResponse>, Status>
pub async fn watch_ref_updates( &mut self, request: impl IntoRequest<WatchRefUpdatesRequest>, ) -> Result<Response<Streaming<RefUpdateEvent>>, Status>
Sourcepub async fn get_change(
&mut self,
request: impl IntoRequest<GetChangeRequest>,
) -> Result<Response<GetChangeResponse>, Status>
pub async fn get_change( &mut self, request: impl IntoRequest<GetChangeRequest>, ) -> Result<Response<GetChangeResponse>, Status>
JJ change metadata (read-only)
pub async fn get_change_history( &mut self, request: impl IntoRequest<GetChangeHistoryRequest>, ) -> Result<Response<GetChangeHistoryResponse>, Status>
pub async fn watch_evo_log( &mut self, request: impl IntoRequest<WatchEvoLogRequest>, ) -> Result<Response<Streaming<EvoLogEvent>>, Status>
Sourcepub async fn watch_change_ops(
&mut self,
request: impl IntoRequest<WatchChangeOpsRequest>,
) -> Result<Response<Streaming<OpEvent>>, Status>
pub async fn watch_change_ops( &mut self, request: impl IntoRequest<WatchChangeOpsRequest>, ) -> Result<Response<Streaming<OpEvent>>, Status>
Working-copy invalidation stream for VFS/SDK consumers. Streams op-derived invalidations for a change with a resumable cursor.
Sourcepub async fn get_object_meta(
&mut self,
request: impl IntoRequest<GetObjectMetaRequest>,
) -> Result<Response<GetObjectMetaResponse>, Status>
pub async fn get_object_meta( &mut self, request: impl IntoRequest<GetObjectMetaRequest>, ) -> Result<Response<GetObjectMetaResponse>, Status>
Object/commit/tree primitives
pub async fn has_objects( &mut self, request: impl IntoRequest<HasObjectsRequest>, ) -> Result<Response<HasObjectsResponse>, Status>
pub async fn get_commit( &mut self, request: impl IntoRequest<GetCommitRequest>, ) -> Result<Response<GetCommitResponse>, Status>
pub async fn batch_get_commits( &mut self, request: impl IntoRequest<BatchGetCommitsRequest>, ) -> Result<Response<BatchGetCommitsResponse>, Status>
Sourcepub async fn list_commits(
&mut self,
request: impl IntoRequest<ListCommitsRequest>,
) -> Result<Response<ListCommitsResponse>, Status>
pub async fn list_commits( &mut self, request: impl IntoRequest<ListCommitsRequest>, ) -> Result<Response<ListCommitsResponse>, Status>
Walk commit ancestors starting from a given commit OID.
Sourcepub async fn list_tree(
&mut self,
request: impl IntoRequest<ListTreeRequest>,
) -> Result<Response<ListTreeResponse>, Status>
pub async fn list_tree( &mut self, request: impl IntoRequest<ListTreeRequest>, ) -> Result<Response<ListTreeResponse>, Status>
List a tree by tree OID.
Sourcepub async fn batch_get_tree_entries(
&mut self,
request: impl IntoRequest<BatchGetTreeEntriesRequest>,
) -> Result<Response<BatchGetTreeEntriesResponse>, Status>
pub async fn batch_get_tree_entries( &mut self, request: impl IntoRequest<BatchGetTreeEntriesRequest>, ) -> Result<Response<BatchGetTreeEntriesResponse>, Status>
Point lookups within a tree by name.
Sourcepub async fn list_dir(
&mut self,
request: impl IntoRequest<ListDirRequest>,
) -> Result<Response<ListDirResponse>, Status>
pub async fn list_dir( &mut self, request: impl IntoRequest<ListDirRequest>, ) -> Result<Response<ListDirResponse>, Status>
View-based directory listing (commit or change).
Sourcepub async fn resolve_path(
&mut self,
request: impl IntoRequest<ResolvePathRequest>,
) -> Result<Response<ResolvePathResponse>, Status>
pub async fn resolve_path( &mut self, request: impl IntoRequest<ResolvePathRequest>, ) -> Result<Response<ResolvePathResponse>, Status>
Resolve one path in a view (server-side traversal).
Sourcepub async fn batch_stat(
&mut self,
request: impl IntoRequest<BatchStatRequest>,
) -> Result<Response<BatchStatResponse>, Status>
pub async fn batch_stat( &mut self, request: impl IntoRequest<BatchStatRequest>, ) -> Result<Response<BatchStatResponse>, Status>
Resolve many paths in one view in one RPC.