#[repr(i32)]pub enum ObjectKind {
Unspecified = 0,
Blob = 1,
Tree = 2,
Commit = 3,
Tag = 4,
}Expand description
Object type as stored in objects.kind.
Variants
Implementations
Sourceimpl ObjectKind
impl ObjectKind
Sourceimpl ObjectKind
impl ObjectKind
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.