#[repr(i32)]pub enum RefKind {
Unspecified = 0,
Commit = 1,
Tag = 2,
Blob = 3,
Tree = 4,
Other = 5,
}Expand description
Ref kind as stored in refs.kind.
Variants
Implementations
Sourceimpl RefKind
impl RefKind
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.