#[repr(i32)]pub enum TreeEntryKind {
Unspecified = 0,
Blob = 1,
Tree = 2,
Commit = 3,
Symlink = 4,
}Expand description
Tree entry kind as stored in tree_entries.kind. Note: mode still carries authoritative git semantics; kind is a convenience.
Variants
Unspecified = 0
Blob = 1
Tree = 2
Commit = 3
Submodule / gitlink.
Symlink = 4
Convenience for mode 120000; may still be backed by a blob.
Implementations
Sourceimpl TreeEntryKind
impl TreeEntryKind
Sourceimpl TreeEntryKind
impl TreeEntryKind
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.