pub enum Content {
BlobOid(Oid),
InlineData(Vec<u8>),
}Variants
BlobOid(Oid)
Preferred for large files: upload first through BlobTransferService (or presigned URL flow).
InlineData(Vec<u8>)
Convenience for small files only; server applies a strict max size limit.
Implementations
Sourceimpl Content
impl Content
Sourcepub fn merge(
field: &mut Option<Content>,
tag: u32,
wire_type: WireType,
buf: &mut impl Buf,
ctx: DecodeContext,
) -> Result<(), DecodeError>
pub fn merge( field: &mut Option<Content>, tag: u32, wire_type: WireType, buf: &mut impl Buf, ctx: DecodeContext, ) -> Result<(), DecodeError>
Decodes an instance of the message from a buffer, and merges it into self.
Sourcepub fn encoded_len(&self) -> usize
pub fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.