GetApplyOpsPolicyResponse

Struct GetApplyOpsPolicyResponse 

pub struct GetApplyOpsPolicyResponse {
    pub inline_data_enabled: bool,
    pub max_inline_data_bytes: u64,
    pub max_ops_per_message: u32,
    pub max_messages_per_stream: u32,
    pub max_total_ops_per_stream: u32,
    pub max_total_inline_data_bytes: u64,
}

Fields

inline_data_enabled: bool

If false, clients must always upload blobs first and reference blob_oid.

max_inline_data_bytes: u64

Maximum bytes allowed for OpCreateFile.inline_data / OpModifyFile.inline_data.

max_ops_per_message: u32

Maximum op count accepted in a single ApplyOps request message.

max_messages_per_stream: u32

Maximum request-message count accepted in a single ApplyOps stream.

max_total_ops_per_stream: u32

Maximum total op count accepted across an entire ApplyOps stream.

max_total_inline_data_bytes: u64

Maximum total inline payload bytes across an entire ApplyOps stream. Includes OpCreateFile.inline_data, OpModifyFile.inline_data, and UTF-8 bytes for OpSetSymlink.target.