pub struct GetObjectMetaResponse {
pub exists: bool,
pub present_in_repo: bool,
pub kind: i32,
pub size_bytes: u64,
}Fields
exists: boolTrue if this oid exists in objects.
present_in_repo: boolTrue if this oid is associated with the repo via repo_objects.
kind: i32size_bytes: u64Implementations
Sourceimpl GetObjectMetaResponse
impl GetObjectMetaResponse
Sourcepub fn kind(&self) -> ObjectKind
pub fn kind(&self) -> ObjectKind
Returns the enum value of kind, or the default if the field is set to an invalid enum value.
Sourcepub fn set_kind(&mut self, value: ObjectKind)
pub fn set_kind(&mut self, value: ObjectKind)
Sets kind to the provided enum value.