pub struct ResolvePathResponse {
pub entry: Option<TreeEntry>,
pub tree_oid: Option<TreeOid>,
}Fields
entry: Option<TreeEntry>The resolved entry for the given path.
tree_oid: Option<TreeOid>If the entry is a directory and the backing tree is materialized, this is the child tree oid.