pub struct TreeEntry {
pub name: String,
pub mode: u32,
pub kind: i32,
pub target_oid: Option<Oid>,
pub size_bytes: u64,
pub symlink_target: String,
}Fields
name: StringName within the tree (single path segment).
mode: u32Git-like mode stored as an integer (e.g. 100644, 100755, 120000, 040000, 160000).
kind: i32target_oid: Option<Oid>size_bytes: u64symlink_target: StringOptional convenience for symlinks.
Implementations
Sourceimpl TreeEntry
impl TreeEntry
Sourcepub fn kind(&self) -> TreeEntryKind
pub fn kind(&self) -> TreeEntryKind
Returns the enum value of kind, or the default if the field is set to an invalid enum value.
Sourcepub fn set_kind(&mut self, value: TreeEntryKind)
pub fn set_kind(&mut self, value: TreeEntryKind)
Sets kind to the provided enum value.